@@ -26,6 +26,17 @@ async fn download_tailwind() {
     assert!(e.exists(), "{:#?}\nFiles: \n{}", meta, ls(&dir))
 }
 
+#[tokio::test]
+async fn download_wasm_opt() {
+    let dir = TempDir::new().unwrap();
+    let meta = Exe::WasmOpt.meta().await.unwrap();
+    let e = meta.with_cache_dir(dir.path()).await;
+    assert!(e.is_ok(), "{e:#?}\n{:#?}\nFiles: \n {}", meta, ls(&dir));
+
+    let e = e.unwrap();
+    assert!(e.exists(), "{:#?}\nFiles: \n{}", meta, ls(&dir))
+}
+
 fn ls(dir: &TempDir) -> String {
     Utf8PathBuf::from_path_buf(dir.path().to_path_buf())
         .unwrap()
