@@ -1,11 +1,14 @@
-use std::collections::{HashMap, HashSet, VecDeque};
-
-use super::dep_graph::{DepGraph, DepNode};
-use super::read::{ExportId, ImportId, InputFuncId, InputModule, SymbolIndex};
-use crate::config::Project;
-use crate::internal_prelude::*;
+use super::{
+    dep_graph::{DepGraph, DepNode},
+    read::{ExportId, ImportId, InputFuncId, InputModule, SymbolIndex},
+};
+use crate::{config::Project, internal_prelude::*};
 use regex::Regex;
-use std::sync::LazyLock;
+use std::{
+    collections::{HashMap, HashSet, VecDeque},
+    hash::Hash,
+    sync::LazyLock,
+};
 
 #[derive(Debug, PartialEq, Eq, Clone)]
 pub struct SplitModule {
@@ -55,10 +58,11 @@ pub fn get_split_points(module: &InputModule) -> Result<Vec<SplitPoint>> {
 
     let split_points = import_map
         .drain()
-        .map(|(key, import_id)| -> Result<SplitPoint> {
-            let export_id = export_map
-                .remove(&key)
-                .ok_or_else(|| anyhow!("No corresponding export for split import {key:?}"))?;
+        .filter_map(|(key, import_id)| -> Option<SplitPoint> {
+            let Some(export_id) = export_map.remove(&key) else {
+                warn!("No corresponding export for split import {key:?}");
+                return None;
+            };
             let export = module.exports[export_id];
             let wasmparser::Export {
                 kind: wasmparser::ExternalKind::Func,
@@ -66,15 +70,17 @@ pub fn get_split_points(module: &InputModule) -> Result<Vec<SplitPoint>> {
                 ..
             } = export
             else {
-                bail!("Expected exported function but received: {export:?}");
+                warn!("Expected exported function but received: {export:?}");
+                return None;
             };
-            let &import_func = module.imported_func_map.get(&import_id).ok_or_else(|| {
-                anyhow!(
+            let Some(import_func) = module.imported_func_map.get(&import_id).copied() else {
+                warn!(
                     "Expected imported function but received: {:?}",
                     &module.imports[import_id]
-                )
-            })?;
-            Ok(SplitPoint {
+                );
+                return None;
+            };
+            Some(SplitPoint {
                 module_name: key.0,
                 import: import_id,
                 import_func,
@@ -82,14 +88,14 @@ pub fn get_split_points(module: &InputModule) -> Result<Vec<SplitPoint>> {
                 export_func: index as InputFuncId,
             })
         })
-        .collect::<Result<Vec<SplitPoint>>>()?;
+        .collect::<Vec<SplitPoint>>();
 
     /* for (key, _) in export_map.iter() {
         bail!("No corresponding import for split export {key:?}");
     } */
 
     if !export_map.is_empty() {
-        bail!(
+        warn!(
             "No corresponding imports for split export(s) {:?}",
             export_map.keys().collect::<Vec<_>>()
         );
@@ -271,11 +277,11 @@ impl SplitModuleIdentifier {
         }
     }
 
-    pub fn name_hashed(&self, proj: &Project) -> String {
+    pub fn hash(&self, proj: &Project) -> String {
         match self {
             Self::Main => proj.lib.output_name.clone(),
-            Self::Split { name, hash } => format!("{name}.{hash}"),
-            Self::Chunk { splits, hash } => format!("{}.{}", splits.join("_"), hash),
+            Self::Split { hash, .. } => hash.clone(),
+            Self::Chunk { hash, .. } => hash.clone(),
         }
     }
 
